@@ -23,6 +23,7 @@ COL_TASK_START = "Task Start"
 COL_TASK_FINISH = "Task Finish"
 COL_TASK_WEEK_PREFIX = "Week Prefix"
 COL_TASK_PROGRESS = "Progress"
+COL_TASK_COSTS = "Costs"
 
 COL_HORIZON_START = "Horizon Start"
 COL_HORIZON_END = "Horizon End"
@@ -53,4 +54,5 @@ EXCEL_COL_NAMES = {
     COL_TASK_EFFORT: "Effort",
     COL_HORIZON_START: "Horizon Start",
     COL_HORIZON_END: "Horizon End",
+    COL_TASK_COSTS: "Costs"
 }
\ No newline at end of file
