@@ -198,6 +198,7 @@ def __tasks_to_excel_tasks(log, wb, tasks_dict, sheet_tasks, date_offset, horizo
         EXCEL_COL_NAMES[COL_HORIZON_START],
         EXCEL_COL_NAMES[COL_HORIZON_END],
         EXCEL_COL_NAMES[COL_TASK_FINISH],
+        EXCEL_COL_NAMES[COL_TASK_COSTS],
         EXCEL_COL_NAMES[COL_TASK_PROGRESS],
     ]
     date_row = [
@@ -209,6 +210,7 @@ def __tasks_to_excel_tasks(log, wb, tasks_dict, sheet_tasks, date_offset, horizo
         for header in header_row
     ]
     col_num_progress = header_row.index(EXCEL_COL_NAMES[COL_TASK_PROGRESS]) + 1
+    col_num_costs = header_row.index(EXCEL_COL_NAMES[COL_TASK_COSTS]) + 1
 
     col_letter_task_start = get_column_letter(header_row.index(EXCEL_COL_NAMES[COL_TASK_START]) + 1)
     col_letter_task_effort = get_column_letter(header_row.index(EXCEL_COL_NAMES[COL_TASK_EFFORT]) +1)
@@ -217,6 +219,7 @@ def __tasks_to_excel_tasks(log, wb, tasks_dict, sheet_tasks, date_offset, horizo
     col_letter_task_lf = get_column_letter(header_row.index(EXCEL_COL_NAMES[COL_TASK_LF]) + 1)
 
     col_letter_progress = get_column_letter(col_num_progress)
+    col_letter_task_costs = get_column_letter(col_num_costs)
     col_letter_task_name = get_column_letter(header_row.index(EXCEL_COL_NAMES[COL_TASK_NAME]) + 1)
 
     groups_to_hide = [
@@ -306,6 +309,7 @@ def __tasks_to_excel_tasks(log, wb, tasks_dict, sheet_tasks, date_offset, horizo
             worktime_start,
             caltime_end,
             formula_task_end,
+            task.costs(),
             task.progress(),
         ]
         content_row.extend([
@@ -516,6 +520,8 @@ def tasks_from_excel(log, path = "tmp/input.xlsx"):
     col_letter_task_effort = common.find_column_for_cell(log, ws, row = HEADER_ROW, cell_value=EXCEL_COL_NAMES[COL_TASK_EFFORT])
     col_letter_task_progress = common.find_column_for_cell(log, ws, row = HEADER_ROW, cell_value=EXCEL_COL_NAMES[COL_TASK_PROGRESS])
 
+    col_letter_task_costs = common.find_column_for_cell(log, ws, row = HEADER_ROW, cell_value=EXCEL_COL_NAMES[COL_TASK_COSTS])
+
     stop = False
 
     # First action in the loop is to increment (there is no do-while loop)
@@ -535,12 +541,15 @@ def tasks_from_excel(log, path = "tmp/input.xlsx"):
         task_effort = ws["{}{}".format(col_letter_task_effort, row_counter)].value
         task_progress = ws["{}{}".format(col_letter_task_progress, row_counter)].value
 
+        task_costs = 0 if not col_letter_task_costs else ws["{}{}".format(col_letter_task_costs, row_counter)].value
+
         tasks_dict[task_id] = task.Task(
             id = task_id,
             name = task_name,
             effort = task_effort,
             progress = task_progress,
             start = task_start,
+            costs = task_costs,
         )
 
     success = True
